/*
 * Definitions for packet ring
 *
 * 2004 - Luca Deri <deri@ntop.org>
 */
#ifndef __RING_H
#define __RING_H


#define INCLUDE_MAC_INFO

#ifdef INCLUDE_MAC_INFO
#define SKB_DISPLACEMENT    14 /* Include MAC address information */
#else
#define SKB_DISPLACEMENT    0  /* Do NOT include MAC address information */
#endif

typedef struct flowSlotInfo {
  u_int tot_slots, slot_len, sample_rate, tot_num_pages, pkts_per_page;
  u_int32_t tot_pkts, tot_lost;
  u_short insert_idx;
  u_short remove_idx;
} FlowSlotInfo;

typedef struct flowSlot {
  u_char     slot_state; /* 0=empty, 1=full   */
  u_char     bucket;     /* bucket[bucketLen] */
} FlowSlot;

/* *********************************** */

#ifndef HAVE_PCAP
struct pcap_pkthdr {
  struct timeval ts;    /* time stamp */
  u_int32_t caplen;     /* length of portion present */
  u_int32_t len;        /* length this packet (off wire) */
};
#endif

/* *********************************** */

#ifdef __KERNEL__ 
FlowSlotInfo* getRingPtr(void);
int allocateRing(char *deviceName, u_int numSlots, u_int bucketLen, u_int sampleRate);
unsigned int pollRing(struct file *fp, struct poll_table_struct * wait);
void deallocateRing(void);

/* ************************* */

typedef int (*handle_ring_skb)(struct sk_buff *skb);
extern void set_ring_handler(handle_ring_skb the_handler);

#endif /* __KERNEL__  */

/* *********************************** */

#define PF_RING          27      /* Packet Ring */
#define SOCK_RING        PF_RING

/* ioctl() */
#define SIORINGPOLL      0x8888

/* *********************************** */

#endif /* __RING_H */
